@@ -23,6 +23,10 @@ class Utils(Object):
 			new = new.dictionary
 		elif isinstance(new, (OutputObject, ResponseObject)):
 			new = new.dict()
+		if not isinstance(new, (dict)):
+			raise dev0s.exceptions.InvalidUsage(f"<website.utils.template>: Parameter [new] requires to be a [dict] not [{new.__class__.__name__}] ({new}).")
+		if not isinstance(old, (dict, Dictionary)):
+			raise dev0s.exceptions.InvalidUsage(f"<website.utils.template>: Parameter [old] requires to be a [dict, Dictionary] not [{new.__class__.__name__}] ({new}).")
 		if isinstance(old, (Dictionary)):
 			l_template_data = dict(old.dictionary)
 		else:
@@ -39,9 +43,7 @@ class Utils(Object):
 			if isinstance(value, (OutputObject, ResponseObject)):
 				value = value.dict()
 			new = {}
-			print(f"===============\nITERATE: {value}")
 			for key, _value_ in value.items():
-				print(f"===============\nINSIDE ITERATE: {_value_}")
 				new[key] = self.serialize_template(_value_)
 			return new
 		elif isinstance(value, (list, Array)):
